@@ -36,14 +36,14 @@ class MyPaintWidget(Widget):
             if len(last_stroke) > 0:
                 recording.append(last_stroke)
                 last_stroke = []
-            point = {"x": touch.x, "y": touch.y, "time": unix_time()}
+            point = {"x": touch.x, "y": -touch.y, "time": unix_time()}
             last_stroke.append(point)
 
     def on_touch_move(self, touch):
         global last_stroke
         touch.ud['line'].points += [touch.x, touch.y]
         # Record keeping
-        point = {"x": touch.x, "y": touch.y, "time": unix_time()}
+        point = {"x": touch.x, "y": -touch.y, "time": unix_time()}
         last_stroke.append(point)
 
 
